vfbLib.parsers.bitmap.GlyphBitmapParser
=======================================

.. currentmodule:: vfbLib.parsers.bitmap

.. autoclass:: GlyphBitmapParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphBitmapParser.__init__
      ~GlyphBitmapParser.parse
      ~GlyphBitmapParser.parse_bitmap_data
      ~GlyphBitmapParser.parse_hex
      ~GlyphBitmapParser.read_double
      ~GlyphBitmapParser.read_doubles
      ~GlyphBitmapParser.read_float
      ~GlyphBitmapParser.read_floats
      ~GlyphBitmapParser.read_int16
      ~GlyphBitmapParser.read_int32
      ~GlyphBitmapParser.read_int8
      ~GlyphBitmapParser.read_str
      ~GlyphBitmapParser.read_str_all
      ~GlyphBitmapParser.read_uint16
      ~GlyphBitmapParser.read_uint32
      ~GlyphBitmapParser.read_uint8
      ~GlyphBitmapParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphBitmapParser.encoding
      ~GlyphBitmapParser.master_count
      ~GlyphBitmapParser.stream
      ~GlyphBitmapParser.ttStemsH_count
      ~GlyphBitmapParser.ttStemsV_count
   
   